@@ -1,7 +1,7 @@
 from .cli import *
 from .hello import *
 
-from .Multiprocessor.CacheCoherence import CacheCoherence
+from .Multiprocessor.CacheCoherence import CacheCoherence, protocols
 from .Multiprocessor.Protocol import Protocol
 from .Multiprocessor.VI_Write_Through import VI
 from .Multiprocessor.MSI import MSI
